SUBSTRATE_INFO <-
structure(c("154-23-4", "22832-87-7", "72-40-2", "97-00-7", "3811-73-2",
"10593-29-0", "5144-89-8", "306-37-6", "57-55-6", "4759-48-2",
"17455-13-9", "2041-14-7", "154-17-6", "33068-19-8", "533-67-5",
"54-21-7", "1562-00-1", "527-73-1", "90-43-7", "366-18-7", "513-85-9",
"431-03-8", "84176-65-8", "51-28-5", "16373-93-6", "951-77-9",
"961-07-9", "890-38-0", "951-78-0", "61-82-5", "513-86-0", "28822-58-4",
"6057-48-3", "146-72-5", "93-03-8", "99-34-3", "504-24-5", "114-63-6",
"51-35-4", "1076-38-6", "56-57-5", "521-18-6", "6559-91-7", "320-67-2",
"130-26-7", "3094-09-5", "2022-85-7", "703-95-7", "51-21-8",
"1190-94-9", "4350-09-8", "91446-96-7", "72-80-0", "773-76-2",
"329-89-5", "53411-70-4", "148-24-3", "10016-20-3", "56401-20-8",
"5989-81-1", "19054-57-0", "21461-84-7", "2013-26-5", "22202-68-2",
"1821-02-9", "3396-99-4", "97-30-3", "617-04-9", "96-27-5", "60-35-5",
"127-09-3", "3483-11-2", "52583-41-2", "57576-44-0", "8048-52-0",
"69235-50-3", "6055-72-7", "58-61-7", "130-49-4", "37063-35-7",
"84-21-9", "37839-81-9", "18422-05-4", "488-81-3", "9002-60-2",
"2482-00-0", "60504-57-6", "1948-31-8", "5874-90-8", "16709-12-9",
"31796-57-3", "20727-65-5", "39537-23-0", "13187-90-1", "687-69-4",
"3253-17-6", "29727-65-9", "3303-34-2", "68973-27-3", "14486-05-6",
"3061-90-3", "13485-59-1", "3303-41-1", "24032-50-6", "16305-75-2",
"3061-88-9", "3303-45-5", "52-39-1", "22573-93-9", "302-79-4",
"97-59-6", "2244-11-3", "645-05-6", "10043-01-3", "39831-55-5",
"52417-22-8", "54-62-6", "549-18-8", "540-69-2", "12125-02-9",
"7783-20-2", "26787-78-0", "69-53-4", "29883-15-6", "10212-25-6",
"118-92-3", "10025-91-9", "65710-07-8", "497-76-7", "40968-45-4",
"15483-27-9", "15706-88-4", "2483-17-2", "15706-89-5", "62632-70-6",
"1188-24-5", "40968-46-5", NA, "2047-13-4", "70921-62-9", "25615-38-7",
"74863-12-0", "2896-20-0", "113-79-1", "20917-58-2", "145314-87-0",
"13433-02-8", "58471-53-7", "13433-13-1", "6157-06-8", "3790-51-0",
"3062-14-4", "5891-51-0", "13433-09-5", "71835-79-5", "13433-04-0",
"51-55-8", "115-02-6", "446-86-6", "461-89-2", "37091-65-9",
"78110-38-0", "34322-87-7", "2672-88-0", "305-84-0", "17136-28-6",
"107-95-9", "51887-89-9", "7585-39-9", "2595-97-3", "50-28-2",
"554-91-6", "1948-48-7", "154804-51-0", "150-83-4", "1824-94-8",
"709-50-2", "134253-42-2", "612-05-5", "53-84-9", "518-29-6",
"156-28-5", "73630-08-7", "14919-77-8", "1670-14-0", "121-54-0",
"633-65-8", "107-43-7", "108-19-0", "3513-03-9", "9041-93-4",
"10043-35-3", "923-06-8", "55-98-1", "2386-54-1", "13952-84-6",
"156-54-7", "462-94-2", "7790-78-5", "58-08-2", "9007-12-9",
"32222-06-3", "10043-52-4", "7689-03-4", "1405-37-4", "1002-62-6",
"10051-44-2", "133-06-2", "72461-86-0", "4800-94-6", "41575-94-4",
"61422-45-5", "154-93-8", "555-60-2", "42540-40-9", "25953-19-9",
"56796-39-5", "62893-20-3", "64485-93-4", "33564-30-6", "52152-93-9",
"104376-79-6", "55268-75-2", "34157-83-0", "58-71-9", "481-49-2",
"7647-17-8", "6004-24-6", "3895-92-9", "305-03-3", "56-75-7",
"56-95-1", "50-63-5", "88-04-0", "69-09-0", "64-72-2", "77-91-8",
"12678-07-8", NA, "617-12-9", "10060-12-5", "140-10-3", "28657-80-9",
"85721-33-1", "585-84-2", "15663-27-1", "498-23-7", "6132-04-3",
"50-41-9", "7081-44-9", "7791-13-1", "64-86-8", "1264-72-8",
"94724-12-6", "10125-13-0", "7758-99-8", "91-64-5", "57-00-1",
"19230-81-0", "548-62-9", "68-19-9", "66-81-9", "6055-19-2",
"19246-18-5", "535-34-2", "156-57-0", "3724-89-8", "147-94-4",
"6018-48-0", "85-94-9", "15718-51-1", "84-52-6", "3616-08-8",
"6757-06-8", "71-30-7", "669-90-9", "70195-25-4", "80731-10-8",
"923-16-0", "3997-90-8", "77286-90-9", "67113-60-4", "338-69-2",
"627-95-2", "5451-09-2", "10323-20-3", "488-82-4", "5794-24-1",
"1783-96-6", "58-85-5", "528-50-7", "6236-10-8", "68-41-7", "207121-46-8",
"57-48-7", "26177-86-6", "3615-37-0", "2782-07-2", "1772-03-8",
"59-23-4", "91510-62-2", "527-07-1", "66-84-2", "70442-23-8",
"3646-68-2", "50-99-7", "3671-99-6", "14984-34-0", "6893-26-1",
"17392-83-5", "81025-04-9", "38689-30-4", "997-05-7", "3303-29-5",
"923-27-3", "636-61-3", "6363-53-7", "69-65-8", "5505-63-5",
"3458-28-4", "99749-54-9", "33068-18-7", "10030-67-8", "585-99-9",
"348-67-4", "137-08-6", "551-68-8", "17629-30-0", "5336-08-3",
"50-69-1", "576-42-1", "138-52-3", "312-84-5", "50-70-4", "87-81-0",
"147-71-7", "632-20-2", "6138-23-4", "640-68-6", "58-86-6", "2835-81-6",
"644-90-6", "3325-00-6", "1077-28-7", "461-05-2", "2577-62-0",
"67-21-0", "65144-02-7", "50-21-5", "940-69-2", "6915-15-7",
"36207-43-9", "674-26-0", "770-05-8", "318-98-9", "55779-32-3",
"50-76-0", "20830-81-3", "138-14-7", "522-17-8", "64-73-3", "522-51-0",
"50-02-2", "9004-53-9", "10465-78-8", "120-46-7", "362-74-3",
"1085-98-9", "90-89-1", "5490-27-7", "96-26-4", "7314-30-9",
"97-77-8", "13473-25-1", "1119-94-4", "2439-10-3", "538-71-6",
"23214-92-8", "10592-13-9", "608-66-2", "60-32-2", "96702-03-3",
"6381-92-6", "13368-13-3", NA, "476-66-4", "483-18-1", "518-82-1",
"74011-58-8", "51-43-4", "114-07-8", "22668-01-5", "141-43-5",
"536-33-4", "75-04-7", "107-21-1", "333-18-6", "33419-42-0",
"130391-54-7", "370-86-5", "10025-77-1", NA, "50-91-9", "86386-73-4",
"59-30-3", "75-12-7", "566-48-3", "17013-01-3", "3759-92-0",
"536-69-6", "751-94-0", "56-12-2", "17465-86-0", "6729-55-1",
"1948-29-4", "502-85-2", "149-91-7", NA, "9000-70-8", "108321-42-2",
"1405-41-0", "304853-26-7", "54419-93-1", "88830-90-4", "2650-65-9",
"21064-18-6", "3918-84-1", "3929-61-1", "13716-89-7", "5875-38-7",
"38101-59-6", "3422-39-7", "5879-06-1", "9007-92-5", "3789-97-7",
"70-18-8", "3695-73-6", "18635-55-7", "1999-33-3", "4685-12-5",
"57281-78-4", "691-81-6", "17343-03-2", "82660-87-5", "7361-42-4",
"10521-49-0", "13115-71-4", "7412-78-4", "556-50-3", "19729-30-7",
"71184-74-2", "556-33-2", "69242-40-6", "14857-82-0", "6234-26-0",
"2489-13-6", "49557-75-7", "19461-38-2", "869-19-2", "31461-63-9",
"554-94-9", "3321-03-7", "13116-21-7", "704-15-4", "7361-43-5",
"7093-70-1", "2390-74-1", "658-79-7", "1963-21-9", "56-81-5",
"56-40-6", "5349-80-4", "9005-79-2", "79-14-1", "563-96-2", "303-45-7",
"1455-77-2", "50-01-1", "635-39-2", "118-00-3", "6027-83-4",
"15718-49-7", "97416-83-6", "40732-48-7", "5550-12-9", "486-84-0",
"15489-90-4", "70-30-4", "10534-89-1", "9002-72-6", "16874-75-2",
"41658-60-0", "53634-28-9", "2578-58-7", "306-14-9", "7763-65-7",
"151151-29-0", "2488-11-1", "20930-58-9", "21438-60-8", "23403-90-9",
"35979-00-1", "76019-15-3", "56-92-8", "50-23-7", "5470-11-1",
"127-07-1", "31282-04-9", "10039-56-2", "300-84-5", "68-94-0",
"31121-93-4", NA, "67763-96-6", NA, "110942-02-4", NA, NA, "24787-73-3",
"55715-01-0", "59652-59-4", NA, "868-28-0", "97284-12-3", "42537-99-5",
"26462-22-6", "42384-14-5", "22951-98-0", "37462-92-3", "6403-14-1",
"13589-06-5", "38579-21-4", "41017-96-3", "700-06-1", "58-63-9",
"14306-25-3", "9004-10-8", "9005-80-5", "7553-56-2", "305-53-3",
"146-68-9", "54-85-3", "97-65-4", "16846-24-5", "481-39-0", "25389-94-0",
"22071-15-4", "33208-99-0", "56-41-7", "87-72-9", "7643-75-6",
"1119-34-2", "35832-00-9", "70-47-3", "3792-50-5", "1955-68-6",
"44985-71-9", "372-75-8", "23537-25-9", "7048-04-6", "1115-65-7",
"28052-93-9", "2438-80-4", "1668-08-2", "921-60-8", "6106-04-3",
"1955-67-5", "56-85-9", "5934-29-2", "156-86-5", "672-15-1",
"2185-02-6", "73-32-5", "312-85-6", "61-90-5", "657-27-2", "1949-78-6",
"138-09-0", "63-68-3", "7314-32-1", "3226-65-1", "327-57-1",
"6600-40-4", "3184-13-2", "63-91-2", "147-85-3", "98-79-3", "3615-41-6",
"56-45-1", "87-79-6", "6106-24-7", "72-19-5", "73-22-3", "60-18-4",
"72-18-4", "4618-18-2", "9008-22-4", "922-55-4", "14933-08-5",
"83-72-7", "75706-12-6", "169494-85-3", "7298-84-2", "26607-15-8",
"14608-81-2", "32949-40-9", "30806-09-8", "17665-02-0", "16364-31-1",
"686-50-0", "1187-50-4", "38062-72-5", "36077-41-5", "3303-31-9",
"10329-75-6", "36077-39-1", "3063-05-6", "87178-63-0", "6209-12-7",
"5156-22-9", "968-21-8", "13588-95-9", "137-58-6", "859-18-7",
"7447-41-8", "98079-51-7", "9002-67-9", "33515-09-2", "17043-71-9",
"29586-66-1", "20556-18-7", "45234-02-4", "40719-58-2", "20556-13-2",
"7369-79-1", "13184-13-9", "97729-52-7", "4078-58-4", "52766-27-5",
"275366-32-0", "97791-84-9", "50674-18-5", "35978-98-4", "20556-11-0",
"149-32-6", "621-37-4", "147-73-9", "7786-30-3", "26522-85-0",
"585-88-6", "1109-28-0", "13446-34-9", "9036-88-8", "51-75-2",
"70803-54-2", "57414-02-5", "6112-76-1", "3061-96-9", "60461-10-1",
"14595-65-4", "17136-27-5", "36261-62-8", "14517-44-3", "14486-03-4",
"14486-12-5", "40883-17-8", "14486-16-9", "45214-88-8", "7349-78-2",
"14492-14-9", "142702-34-9", "40883-16-7", "60535-02-6", "13589-04-3",
"14486-13-6", "75-75-2", "59-05-2", "600-22-6", "1910-42-5",
"593-51-1", "39478-93-8", "66-27-3", "5137-55-3", "58066-85-6",
"13614-98-7", "50-07-7", "65271-80-9", "3878-55-5", "315-22-0",
"1132-61-2", "64953-12-4", "526-99-8", "88671-89-0", "24280-93-1",
"87-89-8", "529-44-2", "7772-94-3", "14215-68-0", "7512-17-6",
"4271-28-7", "71463-44-0", "616-91-1", "1188-37-0", "2490-97-3",
"131-48-6", "110-58-7", "109-73-9", "1118-68-9", "340-90-9",
"7647-14-5", "7177-50-6", "3374-05-8", NA, "1405-10-3", "466-07-9",
"139-88-8", "7791-20-0", "98-92-0", "59-67-6", "42471-28-3",
"67-20-9", "59-87-0", NA, "31430-18-9", "500-38-9", "51-41-2",
"70458-96-7", "1476-53-5", "1400-61-9", "73913-63-0", "108321-25-1",
"407-41-0", "1114-81-4", "21820-51-9", "1071-23-4", "34522-32-2",
"82419-36-1", "7060-74-4", "16773-42-5", "154-85-8", "341-69-5",
"7240-38-2", "62-76-0", "328-42-7", "89304-26-7", "14698-29-4",
"5259-88-1", "2058-46-0", "515-74-2", "555-06-6", "60-17-3",
"156-38-7", "13718-94-0", "7647-10-1", "120-89-8", "68893-82-3",
"1263-89-4", "149-29-1", NA, "9000-69-5", "69-57-8", "4599-60-4",
"87-86-5", "140-64-7", "536-59-4", "3918-87-4", "22828-05-3",
"54745-27-6", "3617-45-6", "721-90-4", "23576-42-3", "22951-94-6",
"15080-84-9", "2577-40-4", "7669-65-0", "16053-39-7", "24587-41-5",
"17355-18-9", "3918-90-9", "132-93-4", "104594-70-9", "329-98-6",
"637-03-6", "11006-33-0", "13147-57-4", "108321-86-4", "19333-65-4",
"5541-93-5", "26016-99-9", "4408-78-0", "4826-71-5", "10083-24-6",
"477-47-4", "51940-44-4", "59703-84-3", "54-91-1", "481-42-5",
"518-28-5", "26124-78-7", "1405-20-5", NA, "7447-40-7", "7789-00-6",
"123333-66-4", "6856-31-1", "6422-36-2", "2418-74-8", "107856-82-6",
"85227-98-1", "18668-08-1", "67644-00-2", "2578-57-6", "18684-24-7",
"51926-51-3", "52899-07-7", "71227-70-8", "13589-02-1", "76932-06-4",
NA, "35310-39-5", "19786-36-8", "52899-09-9", "51-05-8", "1811-28-5",
"57-83-0", "9002-62-4", "58-33-3", "60207-90-1", "137-40-6",
"53597-25-4", "58-58-2", "333-93-7", "65-22-5", "524-36-7", "58-56-0",
"72909-34-3", "113-24-6", "117-39-5", "83-89-6", "77-95-2", "89-00-9",
"53123-88-9", NA, "83-88-5", "13292-46-1", "14897-39-3", "88747-56-2",
"751-97-3", "83-79-4", "11103-72-3", "1187-84-4", "5578-73-4",
"107-97-1", "111-20-6", "469-90-9", "563-41-7", "13909-09-6",
"6403-17-4", "81466-41-3", "2543-31-9", "94421-66-6", "6403-16-3",
"687-63-8", "67726-09-4", "6665-16-3", "3227-09-6", "16875-28-8",
"23827-93-2", "6620-95-7", "21435-27-8", "51782-06-0", "138-59-0",
"53179-09-2", "10048-95-0", "26628-22-8", "532-32-1", "7789-38-0",
"1984-06-1", "917-61-3", "143-33-9", "7789-12-0", "7681-49-4",
"141-53-7", "72-17-3", "7784-46-5", "15293-77-3", "7790-28-5",
"13517-24-3", "13718-26-8", "10102-40-6", "7631-99-4", "7632-00-0",
"13721-39-6", "7601-54-9", "7722-88-5", "13410-01-0", "10102-18-8",
"7757-82-6", "7772-98-7", "10213-10-2", "126-17-0", "110-44-1",
"21736-83-4", "334-50-9", "306-67-2", "8025-81-8", "54261-98-2",
"3810-74-0", "18883-66-4", "638-32-4", "6106-21-4", "57-50-1",
"80-32-0", "547-32-0", "1981-58-4", "723-46-6", "1220-83-3",
"63-74-1", "7727-73-3", "144-74-1", "127-69-5", "10540-29-1",
"1401-55-4", "107-35-7", "145-42-6", "64-75-5", "126-33-0", "13721-29-4",
"1871-22-3", "1719-71-7", "563-68-8", "4099-35-8", "67-03-8",
"154-87-0", "15318-45-3", "1892-29-1", "154-42-7", "10489-48-2",
"130-61-0", "147-93-3", "52-24-4", "62-56-6", "56217-50-6", "13448-26-5",
"108320-97-4", "96337-79-0", "54532-73-9", "686-44-2", "50299-12-2",
"90729-28-5", "16875-27-7", "281670-51-7", "61043-86-5", "50-89-5",
"76567-90-3", "108320-91-8", "33430-62-5", "65-71-4", "9002-71-5",
"24305-27-9", "7488-70-2", "19387-91-8", NA, "32986-56-4", "731-27-1",
"99-14-9", "3380-34-5", "78-40-0", "440-17-5", "70-00-8", "535-83-1",
"6893-02-3", "7785-84-4", "23256-42-0", "75-50-3", "1184-78-7",
"15091-98-2", "2751-09-9", "24046-71-7", "88831-09-8", "71835-78-4",
"36099-95-3", "7360-09-0", "13123-35-8", "51790-14-8", "6686-02-8",
"133101-40-3", "20696-60-0", "19653-76-0", "24613-12-5", "547-25-1",
"9005-64-5", "9005-66-7", "9005-67-8", "9005-65-6", "74610-55-2",
"730-08-5", "28252-40-6", "2545-89-3", "673-08-5", "21778-69-8",
"3788-44-1", "40829-32-1", "17355-10-1", "54925-88-1", "17355-11-2",
"60815-41-0", "1050-28-8", "17355-09-8", "60-19-5", "93-35-6",
"66-22-8", "57-13-6", "124-43-6", "51-79-6", "1198-77-2", "58-96-8",
"56070-25-8", "15718-50-0", "35170-03-7", "56632-58-7", "3387-36-8",
"104-98-3", "27493-61-4", "37682-75-0", "66170-00-1", "20556-16-5",
"42854-54-6", "3062-07-5", "686-43-1", "13589-07-6", "20556-14-3",
"95977-55-2", "22677-62-9", "14486-09-0", "3918-92-1", "105931-64-4",
"13588-94-8", "3061-91-4", "17355-22-5", "3918-94-3", "1404-93-9",
"865-21-4", "7732-18-5", "107021-38-5", "108789-36-2", NA, "125229-64-3",
NA, "7240-90-6", NA, "15548-60-4", "18656-89-8", "129541-42-0",
"102185-33-1", "6578-07-0", "1196-43-6", "5968-90-1", "87-99-0",
"142561-96-4", "30516-87-1", "7646-85-7", "15600", "6924", "2030",
"34718", "36578", "42896", "44975", "73755", "16997", "6067",
"32397", "15573", "15866", "16043", "28816", "16914", "1157",
"67135", "17043", "30351", "62064", "16583", "73908", "42017",
"17256", "15698", "17172", "28997", "16450", "40036", "15688",
"48518", "73916", "73918", "62150", "73914", "34385", "30763",
"18240", "40070", "16907", "16330", "74422", "2038", "74460",
"31521", "5100", "74498", "46345", "51807", "17780", "17426",
"74500", "59477", "74514", "48928", "48981", "40585", "29042",
"17716", "1148", "74524", "16763", "30915", "33033", "55507",
"320061", "43943", "74537", "27856", "15366", "15344", "74545",
"74619", "2432", "74728", "16708", "16335", "28223", "60879",
"28931", "17489", "16027", "15963", "3892", "17431", "74758",
"72816", "73313", "28712", "73330", "73803", "73788", "61565",
"73757", "73771", "73805", "73770", "27749", "73806", "73807",
"73393", "73394", "73762", "73808", "73395", "73809", "27584",
"53661", "15367", "15676", "28315", "24564", "74768", "2637",
"74789", "22526", "2666", "16134", "31206", "62946", "2676",
"28971", "27613", "74843", "30754", "74856", "2790", "18305",
"73810", "73811", "73812", "73813", "63357", "73814", "73815",
"73816", "73817", "73818", "73819", "73821", "73822", "73823",
"34543", "73824", "73825", "73826", "73446", "73827", "73828",
"73450", "68596", "73829", "73830", "73831", "73832", "57858",
"74846", "2948", "53745", "2956", "161680", "73833", "73834",
"15727", "73835", "16958", "17403", "495055", "4093", "16469",
"28066", "28791", "17270", "10983", "17540", "320055", "53688",
"74863", "15846", "74867", "18397", "60888", "31262", "41033",
"31264", "16118", "17750", "18138", "15353", "22907", "33118",
"73712", "28901", "61958", "74526", "30772", "18127", "35456",
"27732", "3306", "17823", "3312", "27656", "3371", "30813", "30776",
"34608", "17672", "3393", "31355", "31360", "3423", "3259", "3481",
"474053", "3489", "3493", "204928", "209807", "3507", "29007",
"3515", "63959", "124991", "3546", "63039", "32915", "31388",
"28830", "17698", "3614", "3638", "34393", "3647", "27644", "15354",
"18296", NA, "17333", "28073", "27386", "3716", "100241", "32805",
"27899", "17626", "30769", "3753", "49566", "27638", "23359",
"37943", "75295", "49553", "28694", "28794", "16919", "16737",
"41688", "17439", "27641", "4026", "4047", "17755", "17141",
"74951", "28680", "17562", "28507", "60877", "53013", "17065",
"17361", "16040", "27469", "17835", "17794", "16576", "73836",
"73837", "73838", "15570", "17549", "15887", "17108", "18333",
"28159", "17364", "15956", "17057", "15586", "40009", "16375",
"15824", "61553", "28847", "15895", "28328", "4139", "18024",
"33198", "17315", "15873", "17784", "4167", "4170", "4178", "15966",
"74611", "75323", "73839", "73840", "73842", "16855", "30796",
"17306", "16899", "62325", "16024", "35374", "17369", "6731",
"28053", "16867", "46905", "27605", "16634", "74168", "47013",
"16002", "17814", "16523", "17924", "16443", "15672", "16398",
"16551", "27477", "53455", "28797", "75145", "15978", "30314",
"17126", "16488", "4886", "75144", "28358", "17460", "15595",
"75415", "28880", "17134", "8500", "75494", "27666", "31456",
"31460", "4357", "4392", "41872", "41879", "28675", "48958",
"75417", "50095", "74875", "4528", "38291", "16016", "16457",
"4659", "74591", "282662", "74889", "31514", "31522", "50845",
"16813", "16586", "27592", "42191", "30740", "75487", "4775",
"4781", "42223", "157175", "28918", "48923", "75473", "16000",
"4885", "15862", "30742", "30347", "4911", "75469", "76458",
"30808", NA, "60761", "46081", "27470", "16397", "75172", "18012",
"74803", "5199", "29013", "16865", "495056", "73843", "73845",
"30830", "30778", "75436", NA, "42768", "17833", "75431", "73846",
"73847", "73848", "73849", "73503", "5390", "73505", "73509",
"73512", "73513", "68846", "5391", "32323", "16856", "73855",
"73860", "73888", "73804", "73890", "73891", "73893", "73895",
"73896", "73897", "73898", "73801", "17201", "73899", "73901",
"63961", "73902", "73904", "73905", "73515", "75430", "73907",
"73514", "73909", "74120", "73912", "73915", "70744", "73516",
"73920", "73921", "73517", "73922", "17754", "15428", "75426",
"28087", "17497", "16891", "28584", "75425", "42820", "16235",
"16750", "74948", "28181", "28072", "16356", "17345", "5623",
"36161", "5693", "63021", NA, "73924", "73925", "73928", "73930",
"74051", "5729", "74052", "74053", "74055", "74056", "74058",
"74059", "74060", "18295", "17650", "15429", "44423", "16976",
"24759", "16668", "17368", "5855", NA, NA, NA, NA, NA, NA, "74062",
"74061", "74063", "74065", "74066", "73520", "74067", "74072",
"74073", "74075", "74076", "74078", "74080", "74326", "74327",
"24814", "17596", "17401", "5931", "15443", "24859", "74571",
"75422", "6030", "30838", "31739", "15794", "6104", "6128", "21217",
"16977", "30849", "18403", "16467", "75419", "17196", "17053",
"52794", "16347", "16349", "17285", "17561", "16345", "6211",
"2181", "17464", "37624", "16015", "75305", "18050", "15971",
"27747", "15699", "30655", "17191", "422", "15603", "18019",
"62320", "30797", "16643", "21363", "17016", "44556", "18314",
"15729", "17295", "17203", "18183", "16055", "17115", "17266",
"15671", "16857", "16828", "17895", "16414", "6359", "6364",
"25013", "75303", "44401", "6402", NA, "73527", "73528", "73529",
"74332", "74527", "74528", "74531", "74534", "74538", "74539",
"74540", "73531", "74541", "73584", "73585", "73580", "73523",
"73590", "73591", "73579", "6456", "6472", "48607", "116278",
NA, "5520", "59621", "74553", "73601", "74557", "73604", "74559",
"74561", "74564", "74566", "73605", "74567", "74568", "73606",
"75669", "73608", "73607", "17113", "17445", "15673", "6636",
"30794", "68428", "61993", "18291", "28808", "28925", "75299",
"28869", "50667", "73610", "74698", "74699", "74700", "74701",
"74702", "73611", "74703", "74704", "74705", "74706", "74707",
"74708", "73612", "73614", "74709", "73615", "73616", "27376",
"44185", "51850", "28786", "16830", "43945", "25255", "75286",
"75283", "50694", "27504", "50727", "75146", "6980", "39074",
"599928", "30852", "75281", "168396", "17268", "18152", "63153",
"28037", "506227", "75278", "21557", "28939", "17533", "21553",
"17012", "74848", "43799", "17724", "75277", "26710", "7447",
"100147", NA, "7507", "7522", "75273", "34887", "17154", "15940",
"75270", "71415", "7592", NA, "34892", "7625", "18357", "100246",
"28368", "7660", "37713", "74959", "15811", "37525", "37788",
"17553", "15805", "7731", "16869", "75176", "16742", "7789",
"7809", "16995", "30744", "30926", "138856", "7858", "27701",
"27500", "30753", "10625", "18101", "18394", "53434", "74661",
NA, "7934", "74926", NA, "17309", "18208", "75258", "17642",
"7977", "10782", "73630", "73631", "74710", "74712", "73635",
"74714", "74717", "74719", "72723", "74750", "71032", "74751",
"73637", "73638", "52427", "8062", "8102", "75253", "75044",
"17150", "18412", "17287", "44897", "28915", "15732", "18132",
"28814", "75251", "72750", "8233", "8242", "8273", "50305", "52412",
"8309", NA, "32588", "75249", "75248", "75247", "74753", "73645",
"74754", "74756", "74757", "74762", "61696", "74767", "74790",
"74791", "74792", "74795", "73646", "73648", "74797", "74799",
"74800", "8430", "8452", "17026", NA, "8461", "8489", "30768",
NA, "17939", "17148", "17310", "57761", "16709", "18315", "32816",
"16243", "8711", "17521", "16675", "9168", NA, "17015", "28077",
"17876", "75246", "63334", "28201", "34956", "45658", "17183",
"15611", "41865", "32488", "28306", "6863", "74801", "74802",
"74807", "74808", "74813", "74814", "73651", "74815", "74817",
"71029", "74820", "73653", "73652", "74823", "16119", "9169",
"18231", "278547", "30746", "75229", "28837", "38906", "33192",
"39483", "28741", "62965", "75228", "29678", "75227", "75226",
"60720", "75221", "75213", "63005", "16301", "35607", "37586",
"71240", "18170", "48843", "32149", "32150", "63940", "9190",
"35962", "45551", "57834", "15746", "9236", "17164", "17076",
"9288", "50398", "15741", "17992", "59057", "9328", "102265",
"9332", "32164", "45373", "16189", "9337", "102484", "41774",
"75211", "507393", "28865", "27902", "74794", "15226", "75198",
"75193", "75192", "497734", "33283", "45931", "32215", "75184",
"9555", "37511", "48566", "59127", "9570", "36946", "74824",
"74825", "74854", "74855", "74857", "74859", "74860", "74861",
"74862", "73662", "73664", "17748", "75183", "55552", "17013",
"17821", NA, "35940", "305790", "63627", NA, "28864", "75182",
"45969", "164200", "45927", "45951", "75179", "18123", "18258",
"27122", "45924", "18139", "15724", "18036", "45735", "73710",
"74866", "74868", "74869", "74870", "74871", "74872", "74874",
"73694", "74876", "74878", "74877", "32528", "53424", "53423",
"53425", "53426", "17658", "74879", "74881", "74883", "74990",
"74991", "73695", "74993", "75003", "75004", "75005", "75006",
"60989", "75007", "15760", "27510", "17568", "16199", "75178",
"17967", "17775", "16704", "28070", "28637", "28895", "75175",
"16695", "27248", "75008", "73711", "73798", "75009", "75010",
"75011", "73699", "73700", "75012", "75013", "75014", "75015",
"75016", "73701", "75021", "73703", "75022", "73704", "28001",
"9984", "15377", "75506", "75502", "75511", "75501", "75513",
"75055", "75512", "75424", "75510", "75498", "75508", "75492",
"15318", "18107", "17151", "75170", "10110", "49976", "C06562",
"C08070", "C04051", "C14397", NA, NA, "C00604", "C19176", "C00583",
"C07058", NA, "C03557", "C00586", "C06369", "C01801", "C00805",
"C05123", "C14531", "C02499", NA, "C03044", "C00741", NA, "C02496",
"C00559", "C00881", "C00330", "C05512", "C00526", "C11261", "C00466",
"C13708", NA, NA, NA, NA, "C13728", "C00156", "C01015", "C20414",
"C03474", "C03917", NA, "C11262", NA, "C12739", NA, NA, "C07649",
"C01211", "C00643", "C01062", NA, NA, NA, "C00345", "C19434",
NA, "C00103", "C00243", "C05984", NA, "C00109", "C00026", "C06255",
NA, NA, NA, NA, "C06244", "C00033", "C00164", NA, "C18638", "C11273",
"C19554", "C00147", "C00212", "C00946", "C02353", "C01367", "C00575",
"C00020", "C00474", "C02017", "C00179", "C18634", NA, NA, "C05340",
NA, NA, NA, NA, NA, NA, NA, NA, "C05341", NA, NA, NA, NA, NA,
NA, NA, NA, "C01780", NA, "C00777", "C01551", "C07599", NA, NA,
"C06820", NA, NA, "C06824", "C00014", "C12538", NA, "C06827",
"C06574", "C08325", "C13112", "C00108", "C15235", "C01555", "C06186",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C13662",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C01479", "C19194",
"C06837", NA, "C06839", "C06840", NA, NA, "C00386", NA, "C00099",
"C02635", "C13183", "C01487", "C00951", "C08240", "C05574", "C02979",
"C01089", "C03619", NA, NA, NA, "C00003", NA, "C05332", NA, NA,
"C01784", "C12539", "C00757", "C00719", "C06555", "C02010", "C06854",
"C12486", NA, "C06862", NA, "C18706", "C00246", "C01672", "C15233",
"C07481", "C06865", "C01673", "C08130", "C01897", "C01790", "C01571",
"C01585", "C14438", "C00169", "C06869", NA, NA, "C06873", "C11164",
"C08102", "C06880", "C08103", "C06883", "C06885", "C08106", "C13505",
"C06683", "C06894", NA, "C07761", "C09391", NA, "C11307", "C12227",
"C06900", "C00918", "C06902", "C07625", "C14715", "C06906", "C06571",
"C00114", "C00635", NA, "C00251", "C06268", "C10438", "C08052",
"C05349", "C00417", "C06911", "C02226", "C00158", "C06917", "C06923",
"C00175", "C07592", "C13768", NA, NA, "C00070", "C05851", "C00300",
"C00791", NA, "C02823", "C06685", "C06933", "C01419", "C00542",
"C01678", NA, "C02961", "C00475", "C03104", "C02354", "C05822",
"C00941", "C00055", "C00380", "C06473", "C00631", "C00197", "C00993",
NA, NA, NA, "C00133", "C00430", "C00431", "C00216", "C01904",
"C01905", "C00402", "C00120", "C00185", "C02612", "C08057", "C00793",
"C00095", "C00085", "C01018", "C03383", "C02262", "C00124", "C00333",
"C00257", "C00329", "C00352", "C03752", "C00031", "C00092", "C00191",
"C00217", NA, NA, NA, NA, NA, "C00739", "C00497", "C00208", "C00392",
"C03570", "C00159", "C00636", "C00275", "C08243", "C05402", "C00855",
"C00864", "C06468", "C00492", NA, "C00121", "C00818", "C01451",
"C00740", "C00794", "C00795", "C02107", "C00820", "C01083", "C06417",
"C00181", "C02261", NA, "C00093", "C00725", "C00487", "C00680",
"C11227", NA, "C01432", "C00248", "C00711", NA, "C02104", "C04227",
"C07407", NA, "C06770", "C01907", "C06940", "C10417", NA, NA,
"C15643", "C00721", "C07080", NA, NA, "C18820", "C07968", "C01023",
"C00184", NA, "C01692", NA, "C20389", "C18723", NA, "C01661",
"C06973", "C01697", "C02378", "C06231", "C00284", NA, NA, "C10788",
"C09421", "C10343", "C06979", "C00788", "C01912", NA, "C00189",
"C07665", "C00797", "C01380", NA, "C01576", "C15893", NA, "C00023",
NA, "C11736", NA, "C00504", "C00488", NA, "C00122", NA, "C10146",
"C06694", "C00334", NA, NA, NA, "C00989", "C01424", NA, "C01498",
"C17703", "C00505", "C16025", NA, NA, NA, NA, NA, "C01425", NA,
NA, NA, NA, NA, "C01501", NA, "C00051", NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, "C02037", NA, NA, NA, NA, NA, NA, NA,
NA, NA, "C02155", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C00116",
"C00037", NA, "C00182", "C00160", "C00048", "C07667", NA, "C17349",
"C00242", "C00387", NA, "C06194", "C06193", "C00942", "C00144",
"C09209", "C06767", "C08039", NA, "C18181", NA, NA, NA, NA, NA,
"C05010", NA, NA, NA, NA, NA, NA, NA, "C00388", "C00735", "C00192",
"C07044", "C01925", NA, "C00519", "C00262", "C01588", NA, "C16131",
NA, "C07903", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, "C00294", "C01204", "C00723", "C03323",
"C00708", NA, NA, "C07054", "C00490", "C12662", "C03840", "C08046",
"C01716", NA, "C00041", "C00259", "C00532", "C00062", NA, "C00152",
"C00049", "C03124", "C00318", "C00327", "C00506", "C00097", "C00606",
"C08275", "C01019", "C01115", NA, "C00025", NA, "C00064", "C00135",
"C01924", "C00263", "C19777", "C00407", "C00186", "C00123", "C00047",
"C01508", "C00149", "C00073", NA, "C02989", "C01933", "C01826",
"C00077", "C00079", "C00148", "C01879", "C00507", "C00065", "C00247",
"C00898", "C00188", "C00078", "C00082", "C00183", "C07064", "C00771",
NA, NA, "C10368", "C07905", "C18188", NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, "C11332", NA, NA, NA, NA, NA, NA, NA, NA,
"C07073", "C06812", NA, "C07078", "C18183", "C07607", NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C00503",
"C05593", "C00552", "C07755", "C00383", NA, "C01835", "C00034",
"C00464", "C07115", NA, "C05377", "C02380", NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C11145",
"C01937", NA, "C00225", "C00218", NA, "C19181", NA, NA, "C07225",
"C06681", "C11195", NA, "C10350", NA, "C07231", "C00879", "C18477",
"C20380", "C00137", "C10107", "C00645", "C01132", "C00140", NA,
"C02712", "C06809", "C00624", NA, "C00270", NA, NA, "C01026",
NA, "C13563", "C07250", "C05079", NA, "C00384", "C08876", NA,
"C14711", "C00153", "C00253", "C11276", "C07268", "C08042", NA,
"C13719", "C10719", "C00547", "C06687", "C05080", "C06572", "C02532",
NA, "C01005", "C12147", "C06501", "C00346", "C04137", "C07321",
"C01946", NA, "C00295", "C07935", "C07334", "C00209", "C00036",
"C01990", "C11342", "C10956", "C06624", "C06335", "C00568", "C11217",
"C00642", "C01742", NA, NA, "C16051", "C00832", "C16748", NA,
"C00714", "C05551", NA, "C02575", "C07420", "C02452", NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C10484",
"C06747", NA, NA, "C00988", "C05945", "C02305", "C00074", "C06454",
"C05682", "C00588", "C05901", "C10871", NA, "C07361", "C07362",
"C10387", "C10874", NA, "C11613", NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C07894",
"C11181", "C00410", "C18201", "C07404", "C11121", "C00163", "C01609",
"C01610", "C00134", "C00250", "C00534", "C00314", "C00113", "C00022",
"C00389", "C07339", "C00296", "C03722", "C07909", "C18190", "C00255",
"C06688", "C01848", NA, "C12933", "C07593", "C13932", NA, "C06162",
"C00213", "C08277", NA, "C02077", "C07640", NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, "C00493", "C00494", "C01478",
"C19935", "C00180", "C19295", "C06423", "C01417", "C00177", "C15227",
"C08142", "C00058", NA, "C11906", NA, NA, NA, NA, "C06232", "C00244",
"C00088", "C11627", "C00009", "C00013", "C05697", "C05684", "C13199",
"C00320", NA, "C10822", NA, "C02078", "C00315", "C00750", "C01754",
"C01613", "C00413", "C07313", NA, "C00042", "C00089", NA, "C07658",
"C19530", "C07315", "C12540", "C07458", "C00059", "C11169", "C07318",
"C07108", "C13452", "C00245", "C05122", "C06570", NA, "C02084",
NA, NA, "C15226", NA, "C00378", "C00068", "C12853", NA, "C07648",
NA, NA, "C08171", "C07641", "C14415", NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, "C00214", NA, NA, "C00364", "C00178", "C18182",
"C03958", "C01829", NA, NA, "C00397", "C18899", "C19806", "C12059",
NA, "C07168", NA, "C01004", "C02465", "C02466", "C01965", "C00565",
"C01104", "C00536", "C12753", NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, "C19636", "C11624", NA, NA, "C11625", "C01457",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "C00483",
"C09315", "C00106", "C00086", NA, "C01537", "C00366", "C00299",
"C03031", "C02355", "C01368", NA, "C00105", "C00785", NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
"C06689", "C11626", "C00001", NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, "C00385", "C01762", "C00379", NA, "C07210", "C00038",
"D00200", "D00882", NA, NA, NA, NA, NA, NA, "D00078", "D00348",
NA, NA, NA, NA, NA, "D00097", NA, NA, "D08367", NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D04127",
NA, NA, NA, NA, "D07456", NA, "D03021", "D03538", "D01309", "D00323",
NA, "D00584", NA, "D07339", NA, "D07208", "D03472", NA, NA, "D05321",
NA, NA, "D00046", NA, NA, NA, NA, NA, NA, NA, NA, "D05075", NA,
"D00010", NA, "D02755", "D02756", NA, NA, "D00034", "D00045",
NA, NA, NA, NA, "D02769", NA, "D00146", NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, "D02804", "D00094", "D00121", "D02365", "D02841", "D08849",
"D02543", "D02905", "D02527", "D00809", "D02916", "D01139", "D08853",
"D07452", "D00204", NA, "D01651", NA, NA, "D02322", NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D02983", NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D00113", "D03032",
"D00238", NA, "D02339", "D00240", NA, NA, NA, NA, "D07561", NA,
"D02401", NA, "D00105", NA, NA, NA, NA, NA, NA, NA, NA, "D00002",
NA, NA, NA, "D01653", NA, "D01140", "D01250", "D07523", NA, NA,
"D07535", "D01089", NA, "D00248", NA, NA, NA, NA, NA, "D00528",
"D00249", "D00129", "D02256", NA, "D07607", NA, NA, NA, NA, "D07614",
"D01363", "D01784", "D00254", NA, "D00909", "D02299", "D00910",
"D07645", "D07647", "D00913", "D07653", "D07659", "D00262", NA,
"D07635", "D01035", "D03446", "D01062", NA, "D00266", "D00104",
"D07668", "D02366", "D03473", "D00270", "D07689", "D07690", NA,
NA, NA, NA, NA, "D00872", "D00186", NA, "D00275", NA, "D00037",
"D00962", "D07733", NA, "D00570", "D02138", NA, "D03612", NA,
"D07751", NA, "D03600", "D01046", "D00166", "D03625", "D00287",
NA, NA, "D03634", NA, "D00168", "D07769", NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, "D07567", NA, NA, NA, NA,
NA, "D00029", NA, NA, "D00877", NA, "D00114", NA, NA, NA, NA,
"D04291", NA, "D05862", "D04334", NA, NA, "D00009", NA, NA, NA,
NA, "D08266", NA, NA, NA, NA, NA, "D00044", "D00062", NA, NA,
NA, NA, NA, NA, NA, "D07413", NA, NA, NA, NA, NA, NA, NA, "D00096",
"D09007", NA, NA, NA, NA, "D06346", NA, NA, NA, "D00086", NA,
NA, NA, NA, "D00111", "D00048", "D04843", NA, NA, NA, "D00483",
NA, "D00214", "D07776", "D01186", NA, "D03680", "D01575", "D00292",
"D00084", "D08144", NA, "D07546", NA, "D00803", "D07840", "D07841",
NA, "D00131", NA, NA, NA, "D01588", "D03899", "D07876", NA, "D00160",
NA, "D00052", "D03967", NA, NA, "D03985", NA, "D00310", "D00095",
"D00140", "D04075", "D05074", "D00591", NA, NA, "D01114", "D00125",
NA, NA, NA, NA, "D04197", "D00322", "D00070", NA, "D07260", "D02308",
"D02510", NA, "D04281", "D00058", NA, NA, NA, "D05866", NA, NA,
"D00115", NA, "D08013", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, "D00116", "D01791", "D00014", NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D00028", "D00011",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D10003",
"D00859", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, "D08040", "D00088", NA, "D00341", NA, NA, NA, NA, "D00126",
NA, NA, NA, "D00748", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, "D00054", NA, "D00085", "D00171",
NA, NA, NA, "D00346", NA, "D01235", NA, "D00866", "D00132", NA,
"D00012", NA, NA, "D02982", NA, "D09738", "D00013", NA, "D02176",
"D07706", NA, "D00026", NA, NA, NA, NA, "D09924", "D00007", NA,
"D00015", "D00032", NA, NA, NA, "D00065", NA, "D00030", "D02304",
NA, NA, "D00019", NA, NA, NA, NA, "D08302", "D00021", "D00035",
NA, NA, "D00016", NA, "D00103", "D00041", "D00020", "D00022",
"D00039", "D00352", NA, NA, NA, NA, "D00749", NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, "D00358", "D00223", NA, "D02318", NA, "D08027", NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D08915",
NA, NA, "D04834", NA, "D04845", NA, NA, NA, "D07671", NA, "D02335",
"D00161", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, "D00142", NA, NA, NA, "D04887", NA, NA,
"D02494", "D05045", "D00208", "D02166", NA, NA, NA, "D08109",
NA, NA, "D05096", "D08079", NA, NA, NA, NA, NA, NA, "D00221",
NA, "D07063", NA, NA, NA, NA, NA, "D02056", "D08242", "D00183",
NA, "D08260", NA, "D06882", NA, "D00036", "D00049", "D08276",
"D00439", "D00862", NA, "D05197", "D04862", "D00076", "D00210",
"D01209", "D00202", NA, NA, NA, NA, NA, NA, NA, "D00453", "D02186",
"D05274", "D00055", "D08305", "D08307", NA, NA, NA, "D02301",
NA, "D00205", NA, "D02456", NA, NA, NA, NA, NA, "D05364", "D07467",
NA, NA, "D02316", "D02336", "D07233", NA, "D00834", NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D08350", NA,
NA, NA, NA, NA, NA, NA, NA, "D04253", "D04254", NA, NA, NA, "D01531",
"D00466", "D00467", NA, "D05529", NA, "D01066", NA, "D02060",
NA, NA, "D02064", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, "D08422", NA, "D00066", NA, "D00480",
NA, "D02310", "D02224", "D05653", NA, NA, NA, "D08454", NA, NA,
NA, "D08179", NA, NA, "D00753", NA, "D00050", "D00211", "D02549",
"D02554", "D02282", NA, NA, NA, NA, NA, NA, NA, NA, "D05822",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D02544",
"D05852", NA, "D02277", NA, "D05220", NA, NA, NA, "D00943", NA,
"D02183", NA, NA, NA, NA, NA, NA, "D02313", "D05865", NA, "D05869",
"D05873", NA, NA, "D01732", "D01091", NA, NA, "D05892", "D08526",
NA, NA, "D05908", NA, "D08531", "D05932", NA, NA, "D00025", "D05948",
"D00587", "D02436", "D00447", "D01141", "D08543", "D05963", "D01047",
"D00450", "D08559", "D01959", "D00047", NA, "D00201", NA, NA,
NA, NA, NA, NA, "D08580", "D01225", "D01407", NA, "D08603", NA,
"D00798", "D00971", "D00583", NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D00176", "D08125", "D01426",
NA, "D00063", NA, NA, "D06226", NA, "D08636", "D00391", NA, "D08128",
"D02423", "D00145", NA, NA, NA, "D01322", NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, "D05565", "D05566", "D05567",
"D01067", "D02490", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, "D00027", "D00023", NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, "D00212", "D01068", "D00001", NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "D00061", NA, "D00413",
"D02058", "CPD-1961", NA, "CPD-3762", "1-CHLORO-24-DINITROBENZENE",
NA, "CPD-3742", "O-PHENANTHROLINE", NA, "PROPANE-1-2-DIOL", NA,
NA, "CPD-1106", "2-DEOXY-D-GLUCOSE", "2-DEOXY-D-GLUCOSE-6-PHOSPHATE",
"2-DEOXYRIBOSE", "CPD-110", "CPD-3745", NA, "CPD-946", "CPD-8819",
"2-3-Butanediols", "DIACETYL", NA, "CPD-8179", "DEOXYADENOSINE",
"DEOXYCYTIDINE", "DEOXYGUANOSINE", "DEOXYINOSINE", "DEOXYURIDINE",
"CPD0-1491", "CPD-255", "CPD-5461", "CPD-3785", "CPD0-1937",
"CPD-12798", NA, NA, "4-hydroxybenzoate", "4-HYDROXY-L-PROLINE",
"CPD-12111", "4-NITROQUINOLINE-N-OXIDE", "17-BETA-HYDROXY-5ALPHA-ANDROSTAN-3-O",
NA, NA, NA, NA, NA, NA, "CPD0-1327", "5-HYDROXY-L-LYSINE", "5-HYDROXY-TRYPTOPHAN",
"5-DEHYDROGLUCONATE", NA, NA, "CPD-9571", "CPD-2961", "8-HYDROXYQUINOLINE",
"CPD-3782", "GLC-1-P", "LACTOSE", "CPD0-2097", "CPD-13414", "2-OXOBUTANOATE",
"2-KETOGLUTARATE", "CPD-3618", "CPD-3565", "CPD-3582", "CPD-3612",
"CPD0-1951", "ACETAMIDE", "ACET", "3-KETOBUTYRATE", "CPD0-1036",
"CPD-12960", NA, NA, "ADENINE", "ADENOSINE", "CPD-3705", "CPD-3707",
"CPD-3706", "CAMP", "AMP", "RIBITOL", NA, "AGMATHINE", NA, NA,
NA, NA, NA, "CPD-13404", "CPD-13403", "CPD0-1445", "ALA-GLY",
"CPD-13401", NA, "CPD-13398", NA, NA, NA, NA, NA, "CPD-13397",
NA, NA, NA, "ALDOSTERONE", NA, "RETINOATE", "ALLANTOIN", "CPD-3684",
NA, NA, NA, NA, NA, NA, "AMMONIA", "NH4CL", "NH42SO4", NA, "CPD-9195",
"CPD-1125", NA, "ANTHRANILATE", "ANTIMONITE", "CPD-14157", "HYDROQUINONE-O-BETA-D-GLUCOPYRANOSIDE",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "ATROPINE", "L-AZASERINE",
NA, NA, NA, "CPD-9235", NA, NA, "CARNOSINE", NA, "B-ALANINE",
"CHLORALAN-CPD", "CPD-3781", "ALLOSE", "CPD-352", "CPD-3605",
NA, "CPD-536", "CPD-335", "METHYL-BETA-D-GALACTOSIDE", "CPD-3570",
"CPD-3611", "CPD-3613", "NAD", "CPD-8960", "PHENYLETHYLAMINE",
NA, NA, NA, NA, "BERBERINE", "BETAINE", "CPD-809", "BLASTICIDIN-S",
"Bleomycins", "BORATE", "CPD-13405", NA, "CPD-3744", "CPD-3627",
"BUTYRIC_ACID", "CADAVERINE", "CPD0-1355", "1-3-7-TRIMETHYLXANTHINE",
NA, "CPD-10582", "CPD0-1589", "CPD-11776", "CAPREOMYCIN", "CPD-3617",
"HEXANOATE", NA, "CARBAMOYL-P", "CPD-9218", NA, NA, NA, "CPD-7970",
"CPD0-2066", NA, NA, NA, "CPD-9232", "CPD-9233", NA, "CPD-12294",
"CPD0-2069", NA, "CPD-9229", NA, "CPD-2", NA, NA, NA, "CHLORAMPHENICOL",
NA, NA, NA, NA, NA, "CHOLINE", "Chondroitin-Sulfate-C", NA, "CHORISMATE",
NA, "CPD-674", NA, "CPD-12843", "CIS-ACONITATE", "CPD0-1392",
"2-METHYLMALEATE", "CIT", NA, "CPD-9225", "CPD0-1695", "CPD-9785",
"CPD-13158", NA, NA, "CU+2", "COUMARIN", "CREATINE", "CREATININE",
NA, "CPD-315", "CPD-7099", NA, "CYS-GLY", "L-CYSTATHIONINE",
"CPD-239", "CPD-3721", "D-ALLOSE-6-PHOSPHATE", "CYTIDINE", "CPD-3710",
"CPD-3713", "CPD-3711", "CPD-683", "CMP", "CYTOSINE", "CPD-377",
"2-PG", "G3P", "D-ALA-D-ALA", NA, NA, NA, "D-ALANINE", "5-AMINO-LEVULINATE",
"CPD0-1950", "D-ARABINOSE", "CPD-355", "CPD-3633", "CPD-302",
"BIOTIN", "CELLOBIOSE", "S-CITRAMALATE", "CPD-2482", "D-CYSTEINE",
"FRU", "FRUCTOSE-6P", "D-FUCOSE", "D-GALACTONO-1-4-LACTONE",
"GALACTOSAMINE", "GALACTOSE", "CPD-12523", "GLUCONATE", "CPD-12538",
"D-GLUCOSAMINE-6-P", "GLUCOSAMINATE", "D-Glucose", "D-glucose-6-phosphate",
"CPD-12521", "D-GLT", "CPD-3621", "CPD0-2460", NA, NA, NA, "CPD-219",
"CPD-660", "MALTOSE", "MANNITOL", "D-Mannosamines", "CPD-12601",
"MANNOSE-1P", "MANNOSE-6P", "CPD-13409", "MELIBIOSE", "CPD-218",
"PANTOTHENATE", "PSICOSE", "CPD-1099", "CPD-13413", "RIBOSE",
"D-GLUCARATE", "CPD-1142", "D-SERINE", "SORBITOL", "TAGATOSE",
"D-TARTRATE", "D-THREONINE", "TREHALOSE", "CPD-3642", "D-Xylose",
"CPD-3686", "CPD-3687", "GLYCEROL-3P", "LIPOIC-ACID", "DL-CARNITINE",
"MESO-DIAMINOPIMELATE", "ETHIONINE", "CPD-13407", "Lactate",
"LIPOAMIDE", "RS-Malate", NA, "CPD-350", "CPD-58", NA, "CPD0-1378",
"ACTINOMYCIN-D", "CPD-13962", "CPD-8951", "CPD-12163", NA, NA,
"CPD-10549", "Dextrins", NA, NA, NA, NA, NA, "CPD-10143", "DIHYDROXYACETONE",
"SS-DIMETHYL-BETA-PROPIOTHETIN", "DISULFIRAM", "CPD-3735", NA,
NA, NA, "CPD-13973", NA, "GALACTITOL", "CPD-884", "ECTOINE",
"EDTA", "EGTA", NA, NA, NA, "CPD-8215", NA, "L-EPINEPHRINE",
"CPD-13804", NA, "ETHANOL-AMINE", NA, "ETHANAMINE", "GLYCOL",
"CPD-3682", NA, NA, "CPD-10715", "CPD0-1693", NA, NA, NA, "CPD-12826",
"FORMAMIDE", NA, "FUM", NA, NA, "CPD0-1606", "4-AMINO-BUTYRATE",
"CPD-3783", NA, NA, "4-HYDROXY-BUTYRATE", "CPD-183", NA, "CPD-13419",
"CPD-14209", "Gentamycins", NA, NA, NA, NA, NA, NA, "CPD-13219",
NA, NA, NA, NA, NA, NA, "CPD0-1656", "GLUTATHIONE", NA, NA, "CPD-13395",
"CPD-13406", NA, NA, NA, NA, NA, NA, "CPD-13394", "CPD-3569",
"GLYCYLGLYCINE", NA, NA, NA, NA, NA, NA, NA, NA, NA, "CPD-12312",
NA, NA, NA, NA, "CPD-10814", NA, NA, NA, NA, NA, "GLYCEROL",
"GLY", NA, "6-alpha-D--1-4-alpha-D-Glucano--Glucan", "GLYCOLLATE",
"GLYOX", "CPD-9526", NA, "CPD0-1470", "GUANINE", "GUANOSINE",
"CPD-13025", "CPD-3709", "CPD-3708", "CGMP", "GMP", "CPD66-92",
"CPD-11677", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, "HISTAMINE", "CORTISOL", "HYDROXYLAMINE", "HYDROXY-UREA",
"HYGROMYCIN-B", NA, "HYPOTAURINE", "HYPOXANTHINE", NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, "CPDQT-428", "INOSINE", "MI-HEXAKISPHOSPHATE", NA,
"Inulin", "IODINE-MOLECULE", "IODOACETATE", "CPD-10339", "ISONIAZIDE",
"ITACONATE", NA, "HYDROXYNAPHTHOQUINONE", "Kanamycins", NA, "CPD-11636",
"L-ALPHA-ALANINE", "L-ARABINOSE", "L-ARABITOL", "ARG", NA, "ASN",
"L-ASPARTATE", "CPD-11551", "CARNITINE", "L-CITRULLINE", "L-CYSTEATE",
"CYS", "L-CYSTEINE_SULFINATE", "CPD-3740", "CPD-10329", "CPD-330",
"CPD-3607", "GLT", NA, "GLN", "HIS", "HOMOARGININE", "HOMO-SER",
"HOMOSERINE-LACTONE", "ILE", "L-LACTATE", "LEU", "LYS", "L-LYXOSE",
"MAL", "MET", "CPD-3739", "L-Methionine-sulfoxides", "L-2-AMINOHEXANOATE",
"L-2-AMINOPENTANOIC-ACID", "L-ORNITHINE", "PHE", "PRO", "5-OXOPROLINE",
"CPD0-1112", "SER", "CPD-9569", "TARTRATE", "THR", "TRP", "TYR",
"VAL", "CPD-3561", "CPD-3602", "CPD-3736", "CPD-10672", "CPD-9608",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "L-LEUCYL-L-LEUCINE",
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "ERYTHRITOL",
"3-HYDROXYPHENYLACETATE", "MESO-TARTRATE", "CPD0-2392", "MALONATE",
"CPD-3609", "MALTOTRIOSE", "CPD0-2394", "Mannan", NA, "CPD-3801",
"CPD-3766", NA, "CPD-13390", NA, NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, "CPD-3746", "CPD-6041", "CPD-3573",
NA, "METHYLAMINE", "CPD-3731", "CPD-7038", NA, NA, NA, NA, NA,
"CPD-3572", NA, "CPD0-1958", NA, "D-GALACTARATE", NA, "CPD-14601",
"MYO-INOSITOL", "MYRICETIN", "N-ACETYL-D-MANNOSAMINE", "CPD-3604",
"CPD-12541", "CPD-3615", "CPD0-2015", "CPD-9175", "ACETYL-GLU",
NA, "CPD0-1122", "CPD-3681", "BUTYLAMINE", "DIMETHYL-GLYCINE",
"CPD-3662", "NACL", NA, NA, NA, NA, NA, NA, "NI+2", "NIACINAMIDE",
"NIACINE", NA, NA, NA, NA, NA, "CPD-7661", "NOREPINEPHRINE",
NA, "CPD-15417", NA, "CPD-3722", "CPD-3729", "3-P-SERINE", "L-THREONINE-O-3-PHOSPHATE",
"CPD-3728", "PHOSPHORYL-ETHANOLAMINE", "CPD-309", NA, "OLEANDOMYCIN",
NA, "OROTATE", NA, "CPD-9224", "OXALATE", "OXALACETIC_ACID",
"CPD-628", NA, NA, NA, "CPD-10427", "P-AMINO-BENZOATE", "CPD0-1900",
"4-HYDROXYPHENYLACETATE", "CPD-230", NA, "CPD-3685", NA, "CPD-14177",
NA, NA, "Pectin", "PENICILLIN-G", NA, "PENTACHLOROPHENOL", NA,
"CPD-261", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
NA, "CPD-9222", NA, "CPD-5541", "CPD-7058", NA, "CPD-67", "L-ARGININE-P",
"CREATINE-P", "PHOSPHO-ENOL-PYRUVATE", "CPD0-1113", "CPD-764",
"PHOSPHORYL-CHOLINE", NA, NA, NA, NA, NA, "CPD-4461", "CPD-8959",
NA, "CPD0-1277", NA, "KCL", "CPD-4422", NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "PROGESTERONE",
NA, NA, "CPD-14540", "PROPIONATE", "PROTAMINE", "PUROMYCIN",
"PUTRESCINE", "PYRIDOXAL", "PYRIDOXAMINE", "PYRIDOXINE", "PQQ",
"PYRUVATE", "CPD-520", "ATABRINE", "QUINATE", "QUINOLINATE",
NA, NA, "RIBOFLAVIN", NA, "CPD-10236", NA, NA, "CPD-5741", NA,
"S-METHYL-L-CYSTEINE", "SANGUINARINE", "SARCOSINE", "CPD-3623",
"CPD-3614", "SEMICARBAZIDE", NA, NA, NA, NA, NA, NA, "CPD-12607",
NA, NA, NA, NA, NA, NA, NA, NA, "SHIKIMATE", NA, "ARSENATE",
"CPD-2841", "BENZOATE", NA, "CPD-195", "CPD-69", NA, NA, NA,
"FORMATE", NA, "CPD0-1496", NA, NA, NA, "CPD-4584", "CPD-3",
"CPD-12921", "NITRITE", NA, "CPD0-2432", "PYROPHOSPHATE-GROUP",
"SELENATE", "SELENITE", "NA2SO4", "S2O3", "TUNGSTATE", "CPD-13080",
"CPD-3624", NA, "SPERMIDINE", "SPERMINE", NA, "CPD-170", "STREPTOMYCIN",
NA, "CPD-8979", "SUC", "SUCROSE", NA, NA, NA, NA, NA, NA, "SULFATE",
"CPD-11285", NA, "CPD-4541", NA, "TAURINE", "CPD-3743", "CPD0-1414",
"CPD-3747", "CPD-14", NA, NA, NA, NA, "THIAMINE", "THIAMINE-PYROPHOSPHATE",
NA, NA, "CPD-5721", "CPD-3734", NA, NA, NA, "CPD-3741", NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, "THYMIDINE", "CPD-3733",
"CPD-3732", "TMP", "THYMINE", NA, NA, "THRYROXINE", NA, NA, NA,
NA, "CPD-3571", "CPD0-1227", "CPD-3703", "CPD-7051", NA, "METHYLNICOTINATE",
"LIOTHYRONINE", "CPD-610", "CPD0-1581", "TRIMETHYLAMINE", "TRIMENTHLAMINE-N-O",
"P3I", NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "CPD-13399",
"CPD-3566", "CPD-3567", "CPD-3767", "CPD-3563", "TYLOSIN", NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "TYRAMINE", "CPD-8186",
"URACIL", "UREA", NA, "URETHAN", "URATE", "URIDINE", "CPD-3723",
"CPD-3725", "CPD-3724", "CPD-3727", "UMP", "UROCANATE", NA, NA,
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA,
"CPD-12245", "CPD-7858", "WATER", NA, NA, NA, NA, NA, NA, NA,
NA, NA, NA, NA, NA, "XANTHINE", "XANTHOSINE", "XYLITOL", NA,
NA, "ZN+2", "Catechin", "Miconazole", NA, "Dinitrochlorobenzene",
"Thiones", "1-thioglucose", "Phenanthrolines", "1,2-Dimethylhydrazine",
"Propylene Glycol", "Isotretinoin", "Crown Ethers", "Aminoethylphosphonic Acid",
"Deoxyglucose", NA, "Deoxyribose", "Sodium Salicylate", "Isethionic Acid",
"Nitroimidazoles", "Biphenyl Compounds", "2,2'-Dipyridyl", "Butylene Glycols",
"Diacetyl", "Pteridines", "2,4-Dinitrophenol", "Deoxyadenosines",
"Deoxycytidine", "Deoxyguanosine", "deoxyinosine", "Deoxyuridine",
"Amitrole", "Acetoin", "1-Methyl-3-isobutylxanthine", "Disaccharides",
"3-O-Methylglucose", "Benzyl Alcohols", "Nitrobenzoates", "4-Aminopyridine",
"Parabens", "Hydroxyproline", "4-Hydroxycoumarins", "4-Nitroquinoline-1-oxide",
"Dihydrotestosterone", "4'-demethylepipodophyllotoxin", "Azacitidine",
"Clioquinol", "Floxuridine", "Flucytosine", "5-fluoroorotic acid",
"Fluorouracil", NA, "5-Hydroxytryptophan", NA, "Chlorquinaldol",
"Chloroquinolinols", "6-Aminonicotinamide", "Gluconates", "Oxyquinoline",
"alpha-Cyclodextrins", NA, "Lactose", "Hydroxybutyrates", NA,
"Butyrates", "Ketoglutaric Acids", "Keto Acids", NA, "Methylglucosides",
"Methylmannosides", "thioglycerol", "Acetamides", "Acetic Acid",
"Acetoacetates", "Isoxazoles", "Aclarubicin", "Acriflavine",
NA, "Adenine", "Adenosine", "Adenosine Monophosphate", "Adenine Nucleotides",
NA, "Cyclic AMP", "Adenosine Monophosphate", "Ribitol", "Adrenocorticotropic Hormone",
"Agmatine", "aclacinomycins", "Dipeptides", "Oligopeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Aldosterone", "Biguanides",
"Tretinoin", "Allantoin", "Alloxan", "Altretamine", "Alum Compounds",
"Amikacin", "Aminacrine", "Aminopterin", "Amitriptyline", "Ammonia",
"Ammonium Chloride", "Ammonium Sulfate", "Amoxicillin", "Ampicillin",
"Amygdalin", "Ancitabine", "ortho-Aminobenzoates", "Chlorides",
"apramycin", "Arbutin", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Arginine Vasopressin", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Atropine", "Azaserine", "Azathioprine", "azauracil", "Azlocillin",
"Aztreonam", NA, NA, "Carnosine", NA, "beta-Alanine", NA, "beta-Cyclodextrins",
NA, "Estradiol", "Disaccharides", "Glutamates", NA, NA, "Methylgalactosides",
"Methylglucosides", NA, "Methylglycosides", "NAD", NA, "Phenethylamines",
"1,2-bis(2-aminophenoxy)ethane-N,N,N',N'-tetraacetic acid", "Benserazide",
"Benzamidines", "Benzethonium", "Berberine", "Betaine", "Biuret",
"Nucleosides", "Bleomycin", "Boric Acids", "Succinates", "Busulfan",
"Alkanesulfonic Acids", NA, "Butyric Acid", "Cadaverine", "Cadmium Chloride",
"Caffeine", "Calcitonin", "Calcitriol", "Calcium Chloride", "Camptothecin",
"Capreomycin", "Decanoic Acids", "Caproates", "Captan", "Carbamyl Phosphate",
"Carbenicillin", "Carboplatin", "1-hexylcarbamoyl-5-fluorouracil",
"Carmustine", "Carbonyl Cyanide m-Chlorophenyl Hydrazone", "cefamandole nafate",
"Cefazolin", "Cefmetazole", "Cefoperazone", "Cefotaxime", "Cefoxitin",
"Cefsulodin", "Ceftriaxone", "Cefuroxime", "Triterpenes", "Cephalothin",
"Benzylisoquinolines", "Chlorides", "Cetylpyridinium", "Benzophenanthridines",
"Chlorambucil", "Chloramphenicol", "Chlorhexidine", "Chloroquine",
"Xylenes", "Chlorpromazine", "Chlortetracycline", "Choline",
"Chondroitin Sulfates", NA, "Chorismic Acid", "Chromium", "Cinnamates",
"Cinoxacin", "Ciprofloxacin", NA, "Cisplatin", "Maleates", "Citric Acid",
"Clomiphene", "Cloxacillin", "Cobalt", "Colchicine", "Colistin",
"p-Methoxy-N-methylphenethylamine", "Copper", "Copper", "Coumarins",
"Creatine", "Creatinine", "Gentian Violet", "Vitamin B 12", "Cycloheximide",
"Cyclophosphamide", "Dipeptides", "Cystathionine", "Cysteamine",
"Cystaphos", "Cytarabine", "Cytidine", NA, "Cytosine Nucleotides",
"Cytidine Monophosphate", "Cyclic CMP", "Cytidine Monophosphate",
"Cytosine", "Gluconates", NA, NA, NA, NA, NA, NA, "Alanine",
"Aminolevulinic Acid", "Amino Acids, Neutral", "Arabinose", "Sugar Alcohols",
"Asparagine", "D-Aspartic Acid", "Biotin", "Cellobiose", NA,
"Cycloserine", "Cysteine", "Fructose", "Fructosephosphates",
"Fucose", NA, "Galactosamine", "Galactose", NA, "Gluconates",
"Glucosamine", NA, "glucosaminic acid", "Glucose", "Glucose-6-Phosphate",
"Glucuronic Acid", "Glutamic Acid", NA, "Sugar Alcohols", NA,
NA, NA, "Lysine", NA, "Maltose", "Mannitol", "Hexosamines", "Mannose",
NA, "Mannosephosphates", "Trisaccharides", "Melibiose", "Methionine",
"Pantothenic Acid", "Fructose", "Raffinose", "Lactones", "Ribose",
"potassium hydrogen glucarate", "Glucosides", "Serine", "Sorbitol",
"Hexoses", NA, "Threonine", "Trehalose", "Valine", "Xylose",
"Aminobutyrates", NA, NA, "Thioctic Acid", "Carnitine", "Diaminopimelic Acid",
"Ethionine", "Amides", "Lactic Acid", "lipoamide", "Malates",
NA, NA, "Octopamine", "Propranolol", "serine hydroxamate", "Dactinomycin",
"Daunorubicin", "Deferoxamine", "deguelin", "Demeclocycline",
"Dequalinium", "Dexamethasone", "Dextrins", "Diamide", "Chalcones",
"Bucladesine", "Aniline Compounds", "Diethylcarbamazine", "Dihydrostreptomycin Sulfate",
"Dihydroxyacetone", "Sulfonium Compounds", "Disulfiram", NA,
"Quaternary Ammonium Compounds", "Guanidines", "Quaternary Ammonium Compounds",
"Doxorubicin", "Doxycycline", "Galactitol", "6-Aminocaproic Acid",
"Amino Acids, Diamino", "Edetic Acid", "Egtazic Acid", NA, "Ellagic Acid",
"Emetine", "Emodin", "Enoxacin", "Epinephrine", "Erythromycin",
"Etanidazole", "Ethanolamine", "Ethionamide", "Ethylamines",
"Ethylene Glycol", "Ethylenediamines", "Etoposide", "Peptides",
"Carbonyl Cyanide p-Trifluoromethoxyphenylhydrazone", "Ferric Compounds",
NA, "Floxuridine", "Fluconazole", "Folic Acid", "Formamides",
"formestane", "Fumarates", "Oxazolidinones", "Fusaric Acid",
"Fusidic Acid", "gamma-Aminobutyric Acid", "gamma-Cyclodextrins",
NA, "Dipeptides", "Sodium Oxybate", "Gallic Acid", "Gastrins",
"Gelatin", "Gentamicins", "Gentamicins", "Ghrelin", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Glucagon", "Glucuronates", "Glutathione", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", NA, NA, NA, NA, NA,
"Dipeptides", "Dipeptides", "Glycylglycine", "Oligopeptides",
NA, "Oligopeptides", "Oligopeptides", "Oligopeptides", "Oligopeptides",
"Dipeptides", "Oligopeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Oligopeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Glycerol",
"Glycine", NA, "Glycogen", "Glycolates", "Glyoxylates", "Gossypol",
"Guanazole", "Guanidine", "Guanine", "Guanosine", "Guanosine Monophosphate",
"Guanine Nucleotides", "Guanosine Monophosphate", "Cyclic GMP",
"Guanosine Monophosphate", "harman", "Hemin", "Hexachlorophene",
"Cobalt", "Growth Hormone", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Histamine", "Hydrocortisone", "Hydroxylamine", "Hydroxyurea",
"Hygromycin B", NA, "hypotaurine", "Hypoxanthine", "Ibuprofen",
NA, "Insulin-Like Growth Factor I", NA, "Interleukin-2", "Interleukin-6",
"Interleukin-8", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Indoles", "Inosine", "Phytic Acid", "Insulin",
"Inulin", "Iodine", "Iodoacetic Acid", "Tetrazolium Salts", "Isoniazid",
"Succinates", "Josamycin", "Naphthoquinones", "Kanamycin", "Ketoprofen",
NA, "Alanine", "Arabinose", NA, "Arginine", NA, "Asparagine",
"Aspartic Acid", NA, "Carnitine", "Citrulline", "Cysteic Acid",
"Cysteine", NA, NA, "Fucose", "Sugar Acids", "Glucose", "Glutamic Acid",
"Hydroxamic Acids", "Glutamine", "Histidine", "Homoarginine",
"Homoserine", NA, "Isoleucine", "Lactic Acid", "Leucine", "Lysine",
NA, NA, "Methionine", "methionine sulfone", NA, "Norleucine",
NA, "Ornithine", "Phenylalanine", "Proline", "Pyrrolidonecarboxylic Acid",
"Rhamnose", "Serine", "Sorbose", NA, "Threonine", "Tryptophan",
"Tyrosine", "Valine", "Lactulose", "Polysaccharides", "Sulfides",
"Quaternary Ammonium Compounds", "Naphthoquinones", "Isoxazoles",
"Leptin", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
NA, NA, "Dipeptides", "Dipeptides", "Oligopeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Oligopeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Lidocaine", "Lincomycin", "Lithium Chloride", "Fluoroquinolones",
"Luteinizing Hormone", "Gonadotropin-Releasing Hormone", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Erythritol", "Phenylacetates", NA, "Magnesium Chloride", "Malonates",
"Sugar Alcohols", "Trisaccharides", "Manganese", "Mannans", "Mechlorethamine",
"Disaccharides", "Vitamin K 3", "6-Mercaptopurine", "Dipeptides",
"Dipeptides", "Dipeptides", NA, "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Mesylates", "Methotrexate", "Pyruvates", "Paraquat",
"Methylamines", "Diphosphonates", "Methyl Methanesulfonate",
"Quaternary Ammonium Compounds", "miltefosine", "Minocycline",
"Mitomycin", "Mitoxantrone", "Succinates", "Monocrotaline", "Morpholines",
"Moxalactam", "Sugar Acids", "Triazoles", "Mycophenolic Acid",
"Inositol", "Flavonoids", "Hexosamines", "Acetylgalactosamine",
"Acetylglucosamine", "N-acetylglucosaminitol", "N-acetylmethionine",
"Acetylcysteine", "Glutamates", "aceglutamide", "N-Acetylneuraminic Acid",
"Amines", "Butylamines", "dimethylglycine", "Glutamates", "Sodium Chloride",
"Nafcillin", "Nalidixic Acid", NA, "Neomycin", "Cardenolides",
"Sodium Tetradecyl Sulfate", "Nickel", "Niacinamide", "Niacin",
"Nimustine", "Nitrofurantoin", "Nitrofurazone", NA, "Nocodazole",
"Nordihydroguaiaretic Acid", "Norepinephrine", "Norfloxacin",
"Novobiocin", "Nystatin", NA, NA, "Plasmalogens", "Phosphothreonine",
"Phosphotyrosine", "Ethanolamines", "octopine", "Ofloxacin",
"Oleandomycin", "Ornidazole", "Orotic Acid", "Orphenadrine",
"Oxacillin", "Oxalic Acid", "Oxaloacetic Acid", "Oxalates", "Oxolinic Acid",
"oxycarboxin", "Oxytetracycline", "Sulfanilic Acids", "4-Aminobenzoic Acid",
"p-Fluorophenylalanine", "Phenylacetates", "isomaltulose", "Palladium",
"Hydantoins", "Parathyroid Hormone", "Paromomycin", "Patulin",
"Platelet-Derived Growth Factor", "Pectins", "Penicillin G",
"Tetracyclines", "Pentachlorophenol", "Pentamidine", "Monoterpenes",
"Dipeptides", "Dipeptides", NA, "Dipeptides", "Dipeptides", "Oligopeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "phenethicillin", "Caffeic Acids",
"Phenylmethylsulfonyl Fluoride", "Arsenicals", "Phleomycins",
"Glycolates", "Organophosphorus Compounds", "Phosphocreatine",
"Phosphoenolpyruvate", "Fosfomycin", "Phosphonoacetic Acid",
"Phosphorylcholine", "Stilbenes", "picropodophyllin", "Pipemidic Acid",
"Piperacillin", "Pipobroman", "Naphthoquinones", "Podophyllotoxin",
NA, "Polymyxin B", NA, "Potassium Chloride", "Potassium Compounds",
"Tellurium", "Piperidines", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Procaine",
"Proflavine", "Progesterone", "Prolactin", "Promethazine", "Triazoles",
"Propionates", "Protamines", "Puromycin", "Putrescine", "Pyridoxal",
"Pyridoxamine", "Pyridoxine", "PQQ Cofactor", "Pyruvic Acid",
"Quercetin", "Quinacrine", "Quinic Acid", "Quinolinic Acid",
"Sirolimus", "Resistin", "Riboflavin", "Rifampin", "Rifamycins",
"Rifamycins", "Rolitetracycline", "Rotenone", "Ruthenium Red",
NA, "Benzophenanthridines", "Sarcosine", "Dicarboxylic Acids",
NA, "Semicarbazides", "Semustine", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Shikimic Acid", "Sisomicin", "Arsenates",
"Sodium Azide", "Sodium Benzoate", "Sodium Compounds", "Caprylates",
"Cyanates", "Sodium Cyanide", "Chromates", "Sodium Fluoride",
"Formates", "Sodium Lactate", "Arsenites", "Borates", "Periodic Acid",
"Silicates", NA, "Molybdenum", "Nitrates", "Sodium Nitrite",
"Vanadates", "Phosphates", "Diphosphates", "Selenium Compounds",
"Sodium Selenite", "Sulfates", "Thiosulfates", "Tungsten Compounds",
"Solanaceous Alkaloids", "Sorbic Acid", "Spectinomycin", "Spermidine",
"Spermine", "Spiramycin", "Oligosaccharides", "Streptomycin",
"Streptozocin", NA, "Succinic Acid", "Sucrose", "Sulfachlorpyridazine",
"Sulfadiazine", "Sulfamethazine", "Sulfamethoxazole", "Sulfamonomethoxine",
"Sulfanilamides", NA, "Sulfathiazoles", "Sulfisoxazole", "Tamoxifen",
"Tannins", "Taurine", "Taurocholic Acid", "Tetracycline", "Thiophenes",
NA, "Tetrazolium Salts", "Tetrazolium Salts", "Organometallic Compounds",
"S-2-aminoethyl cysteine", "Thiamine", "Thiamine Pyrophosphate",
"Thiamphenicol", "Sulfhydryl Compounds", "Thioguanine", "Phosphates",
"Thioridazine", "Sulfhydryl Compounds", "Thiotepa", "Thiourea",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Thymidine", "Thymidine Monophosphate", "3'-thymidylic acid",
"Thymidine Monophosphate", "Thymine", "Thyrotropin", "Thyrotropin-Releasing Hormone",
"Thyroxine", "Tinidazole", NA, "Tobramycin", "Sulfonamides",
"Tricarboxylic Acids", "Triclosan", "Organophosphates", "Trifluoperazine",
"Trifluridine", "Alkaloids", "Triiodothyronine", NA, "Trimethoprim",
"Methylamines", "Methylamines", "Polyphosphates", "Troleandomycin",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Disaccharides", "Polysorbates",
"Polysorbates", "Polysorbates", "Polysorbates", "Tylosin", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Oligopeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Tyramine", "Umbelliferones", "Uracil",
"Urea", "Peroxides", "Urethane", "Uric Acid", "Uridine", NA,
"Uracil Nucleotides", "3'-uridylic acid", "Uridine Monophosphate",
"Uridine Monophosphate", "Urocanic Acid", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides",
"Dipeptides", "Dipeptides", "Dipeptides", "Dipeptides", "Oligopeptides",
"Dipeptides", "Vancomycin", "Vinblastine", "Water", NA, NA, NA,
NA, NA, "Indoles", NA, "Indoles", "Indoles", NA, "Indoles", NA,
"Xanthine", "Ribonucleosides", "Xylitol", "Bicyclo Compounds, Heterocyclic",
"Zidovudine", "Zinc Compounds"), .Dim = c(1062L, 6L), .Dimnames = list(
    NULL, c("CAS", "CHEBI", "KEGG", "DRUG", "METACYC", "MESH"
    )))
